# define kfp component as dataclasses

[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/ml-orchestrator)](https://pypi.org/project/ml-orchestrator/)
[![version](https://img.shields.io/pypi/v/ml-orchestrator)](https://img.shields.io/pypi/v/ml-orchestrator)
[![License](https://img.shields.io/:license-MIT-blue.svg)](https://opensource.org/licenses/MIT)
![OS](https://img.shields.io/badge/ubuntu-blue?logo=ubuntu)
![OS](https://img.shields.io/badge/win-blue?logo=windows)
![OS](https://img.shields.io/badge/mac-blue?logo=apple)
[![Tests](https://github.com/DanielAvdar/ml-orchestrator/actions/workflows/ci.yml/badge.svg)](https://github.com/DanielAvdar/ml-orchestrator/actions/workflows/ci.yml)
[![Code Checks](https://github.com/DanielAvdar/ml-orchestrator/actions/workflows/code-checks.yml/badge.svg)](https://github.com/DanielAvdar/ml-orchestrator/actions/workflows/code-checks.yml)
[![codecov](https://codecov.io/gh/DanielAvdar/ml-orchestrator/graph/badge.svg?token=N0V9KANTG2)](https://codecov.io/gh/DanielAvdar/ml-orchestrator)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
